@@ -21,6 +21,7 @@ from datalad.support.constraints import EnsureNone
 from datalad.support.constraints import EnsureChoice
 from datalad.support.constraints import EnsureListOf
 from datalad.support.constraints import EnsureStr
+from datalad.utils import on_windows
 
 dirs = AppDirs("datalad", "datalad.org")
 
@@ -39,6 +40,8 @@ definitions = {
                'title': 'NDA database server',
                'text': 'Hostname of the database server'}),
         'destination': 'global',
+        # Development one is https://development.nimhda.org
+        'default': 'https://nda.nih.gov/DataManager/dataManager',
     },
     'datalad.locations.cache': {
         'ui': ('question', {
@@ -266,6 +269,13 @@ definitions = {
         'destination': 'global',
         'default': None,
     },
+    'datalad.ssh.multiplex-connections': {
+        'ui': ('question', {
+               'title': "Whether to use a single shared connection for multiple SSH processes aiming at the same target."}),
+        'destination': 'global',
+        'default': not on_windows,
+        'type': EnsureBool(),
+    },
     'datalad.annex.retry': {
         'ui': ('question',
                {'title': 'Value for annex.retry to use for git-annex calls',
