@@ -35,6 +35,7 @@ from datalad.distribution.dataset import datasetmethod
 from datalad.support.exceptions import InsufficientArgumentsError
 from datalad.support.exceptions import NoDatasetFound
 from datalad.utils import (
+    guard_for_format,
     quote_cmdlinearg,
     split_cmdline,
 )
@@ -301,6 +302,15 @@ class RunProcedure(Interface):
         )
     )
 
+    _examples_ = [
+        dict(text="Find out which procedures are available on the current system",
+             code_py="run_procedure(discover=True)",
+             code_cmd="datalad run-procedure --discover"),
+        dict(text="Run the 'yoda' procedure in the current dataset",
+             code_py="run_procedure(spec='cfg_yoda', recursive=True)",
+             code_cmd="datalad run-procedure cfg_yoda"),
+    ]
+
     result_renderer = 'tailored'
 
     @staticmethod
@@ -427,8 +437,8 @@ class RunProcedure(Interface):
                              "Missing 'execute' permissions?" % procedure_file)
 
         cmd = ex['template'].format(
-            script=quote_cmdlinearg(procedure_file),
-            ds=quote_cmdlinearg(ds.path) if ds else '',
+            script=guard_for_format(quote_cmdlinearg(procedure_file)),
+            ds=guard_for_format(quote_cmdlinearg(ds.path)) if ds else '',
             args=(u' '.join(quote_cmdlinearg(a) for a in args) if args else ''))
         lgr.info(u"Running procedure %s", name)
         lgr.debug(u'Full procedure command: %r', cmd)
