@@ -9,11 +9,7 @@
 """Create and update a dataset from a list of URLs.
 """
 
-try:
-    from collections.abc import Mapping
-except ImportError:  # Python <= 3.3
-    from collections import Mapping
-
+from collections.abc import Mapping
 from functools import partial
 import logging
 import os
