@@ -88,6 +88,7 @@ from datalad.tests.utils import (
     skip_if,
     skip_if_on_windows,
     skip_if_root,
+    skip_nomultiplex_ssh,
     skip_ssh,
     SkipTest,
     slow,
@@ -783,12 +784,7 @@ def test_AnnexRepo_commit(path):
         f.write("some")
     assert_raises(FileNotInRepositoryError, ds.commit, files="untracked")
     # not existing file as well:
-    try:
-        ds.commit(files="not-existing")
-    except FileNotInRepositoryError:
-        pass   # expected result
-    except CommandError:
-        raise SkipTest("test_AnnexRepo_commit hit known failure (gh-4773)")
+    assert_raises(FileNotInRepositoryError, ds.commit, files="not-existing")
 
 
 @with_testrepos('.*annex.*', flavors=['clone'])
@@ -980,7 +976,7 @@ def test_AnnexRepo_get_contentlocation():
         yield _test_AnnexRepo_get_contentlocation, batch
 
 
-@known_failure_githubci_win
+@known_failure_windows
 @with_tree(tree=(('about.txt', 'Lots of abouts'),
                  ('about2.txt', 'more abouts'),
                  ('about2_.txt', 'more abouts_'),
@@ -1123,7 +1119,7 @@ def test_annex_backends(path):
     eq_(repo.default_backends, ['MD5E'])
 
 
-@skip_ssh
+@skip_nomultiplex_ssh  # too much of "multiplex" testing
 @with_tempfile(mkdir=True)
 def test_annex_ssh(topdir):
     # On Xenial, this hangs with a recent git-annex. It bisects to git-annex's
@@ -1133,6 +1129,12 @@ def test_annex_ssh(topdir):
     if external_versions['cmd:system-ssh'] < '7.4' and \
        '7.20191230' < external_versions['cmd:annex'] <= '8.20200720.1':
         raise SkipTest("Test known to hang")
+    # And, since the switch to the Docker SSH target, our cron build with
+    # 7.20190708 stalls. 7.20190819 is the first known good version, but do a
+    # minimal skip up until the next release because we don't know that
+    # 7.20190730 stalls.
+    if external_versions['cmd:annex'] < '7.20190730':
+        raise SkipTest("Test known to hang")
 
     topdir = Path(topdir)
     rm1 = AnnexRepo(topdir / "remote1", create=True)
@@ -1204,7 +1206,10 @@ def test_annex_ssh(topdir):
     # copy to the new remote:
     ar.copy_to(["foo"], remote="ssh-remote-2")
 
-    ok_(exists(socket_2))
+    if not exists(socket_2):  # pragma: no cover
+        # @known_failure (marked for grep)
+        raise SkipTest("test_annex_ssh hit known failure (gh-4781)")
+
     ssh_manager.close(ctrl_path=[socket_1, socket_2])
 
 
