@@ -43,7 +43,6 @@ from datalad.config import (
 )
 from datalad.cmd import CommandError
 
-from datalad.support.external_versions import external_versions
 from datalad.support.gitrepo import GitRepo
 from datalad import cfg as dl_cfg
 
@@ -203,11 +202,6 @@ def test_something(path, new_home):
         # but after we unset the only value -- that section is no longer listed
         assert (not globalcfg.has_section('datalad.unittest'))
         assert_not_in('datalad.unittest.youcan', globalcfg)
-        if external_versions['cmd:git'] < '2.18':
-            # older versions leave empty section behind in the file
-            ok_file_has_content(global_gitconfig, '[datalad "unittest"]', strip=True)
-            # remove_section to clean it up entirely
-            globalcfg.remove_section('datalad.unittest', where='global')
         ok_file_has_content(global_gitconfig, "")
 
     cfg = ConfigManager(
